@@ -32,21 +32,21 @@ ENABLE_MOVIT=1
 MOVIT_HEAD=0
 MOVIT_REVISION="origin/shotcut-opengl3"
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/7.1"
+FFMPEG_REVISION="origin/release/8.0"
 FFMPEG_ADDITIONAL_OPTIONS=
 MLT_HEAD=1
 MLT_REVISION=
 LOG_COLORS=0
 SHOTCUT_HEAD=1
 SHOTCUT_REVISION=
-SHOTCUT_VERSION=$(date '+%y.%m.%d')
+SHOTCUT_VERSION=$(date '+%y.%-m.%-d')
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
 BIGSH0T_REVISION="710e734512b8975722f0c41f793f28c51a3d2b88"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.5.0"
+DAV1D_REVISION="1.5.1"
 AOM_HEAD=0
-AOM_REVISION="v3.11.0"
+AOM_REVISION="v3.13.1"
 ENABLE_VMAF=1
 VMAF_HEAD=0
 VMAF_REVISION="v3.0.0"
@@ -58,7 +58,7 @@ ENABLE_OPENCV=1
 OPENCV_HEAD=0
 OPENCV_REVISION="origin/4.x"
 OPENCV_CONTRIB_HEAD=0
-OPENCV_CONTRIB_REVISION="4.11.0"
+OPENCV_CONTRIB_REVISION="4.12.0"
 ENABLE_LIBSPATIALAUDIO=1
 LIBSPATIALAUDIO_HEAD=0
 LIBSPATIALAUDIO_REVISION="origin/patch-1"
@@ -68,13 +68,13 @@ LADSPA_REVISION="origin/shotcut"
 MLT_DISABLE_SOX=0
 ENABLE_WHISPERCPP=1
 WHISPERCPP_HEAD=0
-WHISPERCPP_REVISION="v1.7.4"
+WHISPERCPP_REVISION="v1.8.0"
 NV_CODEC_REVISION="sdk/12.0"
 
 PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
 PYTHON_VERSION_DLL=$(python3 --version | awk '{split($2, parts, "."); print parts[1]parts[2]}')
 
-QT_VERSION_X64="6.9.1"
+QT_VERSION_X64="6.8.3"
 
 ################################################################################
 # Location of config file - if not overridden on command line
@@ -583,7 +583,7 @@ function set_globals {
 
   #####
   # mlt
-  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_GDK=OFF -DMOD_GLAXNIMATE_QT6=ON -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_SDL1=OFF -DUSE_VST2=OFF"
+  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_GDK=OFF -DMOD_GLAXNIMATE_QT6=ON -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_SDL1=OFF -DUSE_VST2=OFF -DMOD_SPATIALAUDIO=ON"
   [ "$ENABLE_OPENCV" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_OPENCV=ON"
   if [ "$DEBUG_BUILD" = "1" ]; then
     CONFIG[1]="${CONFIG[1]} -DCMAKE_BUILD_TYPE=RelWithDebInfo"
@@ -591,7 +591,7 @@ function set_globals {
     CONFIG[1]="${CONFIG[1]} -DCMAKE_BUILD_TYPE=Release"
   fi
   CFLAGS_[1]="-I$FINAL_INSTALL_DIR/include $ASAN_CFLAGS $CFLAGS"
-  CXXFLAGS_[1]="${CFLAGS_[1]} -std=c++11 -D_XOPEN_SOURCE=700"
+  CXXFLAGS_[1]="${CFLAGS_[1]} -D_XOPEN_SOURCE=700"
   LDFLAGS_[1]="-L$FINAL_INSTALL_DIR/lib $ASAN_LDFLAGS $LDFLAGS"
   BUILD[1]="ninja -j $MAKEJ"
   INSTALL[1]="ninja install"
@@ -722,7 +722,7 @@ function set_globals {
 
   #####
   # opencv
-  CONFIG[15]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D BUILD_LIST=tracking -D OPENCV_GENERATE_PKGCONFIG=YES -D OPENCV_EXTRA_MODULES_PATH=../opencv_contrib/modules -D WITH_OPENMP=ON $CMAKE_DEBUG_FLAG"
+  CONFIG[15]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D CMAKE_CXX_STANDARD=14 -D BUILD_LIST=tracking -D OPENCV_GENERATE_PKGCONFIG=YES -D OPENCV_EXTRA_MODULES_PATH=../opencv_contrib/modules -D WITH_OPENMP=ON $CMAKE_DEBUG_FLAG"
   CFLAGS_[15]="$CFLAGS"
   LDFLAGS_[15]="$LDFLAGS"
   BUILD[15]="ninja -C build -j $MAKEJ"
@@ -1227,7 +1227,7 @@ function deploy
 
   log Copying some libs from Qt
   if [ "$DEBUG_BUILD" != "1" -o "$SDK" = "1" ]; then
-    cmd cp -p "$QTDIR"/bin/Qt6{Charts,Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
+    cmd cp -p "$QTDIR"/bin/Qt6{Charts,Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,WebSockets,Widgets,Xml}.dll .
   fi
 
   for lib in *.dll; do
@@ -1258,7 +1258,7 @@ function deploy
   log Copying some libs from msys2
   cmd cp -p /${TARGET_ARCH}/bin/libcrypto-3.dll .
   if [ "$TARGET_ARCH" = "clangarm64" ]; then
-    cmd cp -p /${TARGET_ARCH}/bin/{libjasper.dll,libjpeg-8.dll,libmng-2.dll,liblcms2-2.dll,libtiff-6.dll,libjbig-0.dll,libdeflate.dll,libLerc.dll,libunwind.dll,libwebpdemux-2.dll,libcairo-2.dll,libfontconfig-1.dll,libpixman-1-0.dll,libxml2-2.dll,libomp.dll,libebur128.dll,libsamplerate-0.dll,librubberband-2.dll,libsox-3.dll,libopencore-amrnb-0.dll,libvo-amrwbenc-0.dll,libFLAC.dll,libltdl-7.dll,libgsm.dll,libmad-0.dll,libao-4.dll,libid3tag-0.dll,libtwolame-0.dll,libvorbisfile-3.dll,libwavpack-1.dll,libsndfile-1.dll,libopencore-amrwb-0.dll,libmpg123-0.dll,libopusfile-0.dll,libmysofa.dll,libvidstab.dll,libexpat-1.dll,liblz4.dll,libfftw3f-3.dll} .
+    cmd cp -p /${TARGET_ARCH}/bin/{libjasper.dll,libjpeg-8.dll,libmng-2.dll,liblcms2-2.dll,libtiff-6.dll,libjbig-0.dll,libdeflate.dll,libLerc.dll,libunwind.dll,libwebpdemux-2.dll,libcairo-2.dll,libfontconfig-1.dll,libpixman-1-0.dll,libxml2-16.dll,libomp.dll,libebur128.dll,libsamplerate-0.dll,librubberband-2.dll,libsox-3.dll,libopencore-amrnb-0.dll,libvo-amrwbenc-0.dll,libFLAC.dll,libltdl-7.dll,libgsm.dll,libmad-0.dll,libao-4.dll,libid3tag-0.dll,libtwolame-0.dll,libvorbisfile-3.dll,libwavpack-1.dll,libsndfile-1.dll,libopencore-amrwb-0.dll,libmpg123-0.dll,libopusfile-0.dll,libmysofa.dll,libvidstab.dll,libexpat-1.dll,liblz4.dll,libfftw3f-3.dll} .
   fi
   if [ "$DEBUG_BUILD" = "1" -o "$SDK" = "1" ]; then
     [ "$TARGET_ARCH" != "clangarm64" ] && cmd cp -p "$SOURCE_DIR"/shotcut/drmingw/x64/bin/*.{dll,yes} .
