@@ -38,12 +38,12 @@ X264_REVISION="origin/stable"
 X265_HEAD=0
 X265_REVISION="origin/stable"
 LIBVPX_HEAD=0
-LIBVPX_REVISION="v1.15.0"
+LIBVPX_REVISION="v1.15.2"
 LIBOPUS_HEAD=0
 LIBOPUS_REVISION="v1.5.2"
 ENABLE_SWH_PLUGINS=1
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/7.1"
+FFMPEG_REVISION="origin/release/8.0"
 FFMPEG_SUPPORT_H264=1
 FFMPEG_SUPPORT_H265=1
 FFMPEG_SUPPORT_JACK=0
@@ -70,7 +70,7 @@ MLT_REVISION=
 LOG_COLORS=0
 SHOTCUT_HEAD=1
 SHOTCUT_REVISION=
-SHOTCUT_VERSION=$(date '+%y.%m.%d')
+SHOTCUT_VERSION=$(date '+%y.%-m.%-d')
 ENABLE_RUBBERBAND=1
 RUBBERBAND_HEAD=0
 RUBBERBAND_REVISION="v4.0.0"
@@ -81,11 +81,11 @@ ENABLE_ZIMG=1
 ZIMG_HEAD=0
 ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.5.0"
+DAV1D_REVISION="1.5.1"
 AOM_HEAD=0
-AOM_REVISION="v3.11.0"
+AOM_REVISION="v3.13.1"
 SVTAV1_HEAD=0
-SVTAV1_REVISION="v3.0.2"
+SVTAV1_REVISION="v3.1.0"
 VMAF_HEAD=0
 VMAF_REVISION="v3.0.0"
 ENABLE_GLAXNIMATE=1
@@ -94,25 +94,27 @@ GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.11.0"
+OPENCV_REVISION="origin/4.x"
+OPENCV_CONTRIB_HEAD=0
+OPENCV_CONTRIB_REVISION="4.12.0"
 ENABLE_LIBWEBP=1
 LIBWEBP_HEAD=0
-LIBWEBP_REVISION="v1.5.0"
+LIBWEBP_REVISION="v1.6.0"
 ENABLE_LIBSPATIALAUDIO=1
-LIBSPATIALAUDIO_HEAD=1
-LIBSPATIALAUDIO_REVISION=
+LIBSPATIALAUDIO_HEAD=0
+LIBSPATIALAUDIO_REVISION="origin/patch-1"
 ENABLE_WHISPERCPP=1
 WHISPERCPP_HEAD=0
-WHISPERCPP_REVISION="v1.7.4"
+WHISPERCPP_REVISION="v1.8.0"
 NV_CODEC_REVISION="sdk/12.0"
 MFX_DISPATCH_REVISION="1.25"
 
-PYTHON_VERSION_DEFAULT=3.8
+PYTHON_VERSION_DEFAULT=3.10
 PYTHON_VERSION_DARWIN=3.11
 PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
 
-QT_VERSION_DEFAULT=6.4.3
-QT_VERSION_DARWIN=6.9.1
+QT_VERSION_DEFAULT=6.8.3
+QT_VERSION_DARWIN=6.8.3
 
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
@@ -561,7 +563,7 @@ function set_globals {
   REPOLOCS[3]="https://github.com/mirror/x264.git"
   REPOLOCS[4]="https://chromium.googlesource.com/webm/libvpx.git"
   REPOLOCS[5]="https://github.com/ddennedy/movit.git"
-  REPOLOCS[6]="https://github.com/videolabs/libspatialaudio.git"
+  REPOLOCS[6]="https://github.com/ddennedy/libspatialaudio.git"
   REPOLOCS[7]="https://github.com/mltframework/shotcut.git"
   REPOLOCS[8]="https://github.com/swh/ladspa.git"
   REPOLOCS[9]="https://github.com/OpenMathLib/OpenBLAS.git"
@@ -701,8 +703,8 @@ function set_globals {
     REVISIONS[26]="$OPENCV_REVISION"
   fi
   REVISIONS[27]=""
-  if test 0 = "$OPENCV_HEAD" -a "$OPENCV_REVISION" ; then
-    REVISIONS[27]="$OPENCV_REVISION"
+  if test 0 = "$OPENCV_HEAD" -a "$OPENCV_CONTRIB_REVISION" ; then
+    REVISIONS[27]="$OPENCV_CONTRIB_REVISION"
   fi
   REVISIONS[28]=""
   if test 0 = "$LIBWEBP_HEAD" -a "$LIBWEBP_REVISION" ; then
@@ -831,7 +833,7 @@ function set_globals {
 
   #####
   # mlt
-  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_GLAXNIMATE_QT6=ON -DMOD_GDK=OFF -DMOD_SDL1=OFF -DUSE_VST2=OFF"
+  CONFIG[1]="cmake -GNinja -B build -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_GLAXNIMATE_QT6=ON -DMOD_GDK=OFF -DMOD_SDL1=OFF -DUSE_VST2=OFF -DMOD_SPATIALAUDIO=ON"
   # Remember, if adding more of these, to update the post-configure check.
   [ "$ENABLE_OPENCV" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_OPENCV=ON"
   [ "$MLT_DISABLE_SOX" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_SOX=OFF"
@@ -850,8 +852,8 @@ function set_globals {
   fi
   CXXFLAGS_[1]="${CFLAGS_[1]} -std=c++11"
   LDFLAGS_[1]="${LDFLAGS_[1]} -L$FINAL_INSTALL_DIR/lib $ASAN_LDFLAGS $LDFLAGS"
-  BUILD[1]="ninja -j $MAKEJ"
-  INSTALL[1]="ninja install"
+  BUILD[1]="ninja -C build -j $MAKEJ"
+  INSTALL[1]="ninja -C build install"
 
   #####
   # frei0r
@@ -1097,7 +1099,7 @@ function set_globals {
 
   #####
   # opencv
-  CONFIG[26]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D BUILD_LIST=tracking -D OPENCV_GENERATE_PKGCONFIG=YES -D OPENCV_EXTRA_MODULES_PATH=../opencv_contrib/modules -D WITH_OPENMP=ON $CMAKE_DEBUG_FLAG"
+  CONFIG[26]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D BUILD_LIST=tracking -D OPENCV_GENERATE_PKGCONFIG=YES -D OPENCV_EXTRA_MODULES_PATH=../opencv_contrib/modules -D WITH_OPENMP=ON -D WITH_LAPACK=OFF $CMAKE_DEBUG_FLAG"
   [ "$TARGET_OS" = "Darwin" ] && CONFIG[26]="${CONFIG[26]} -D CMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
   CFLAGS_[26]="$CFLAGS"
   LDFLAGS_[26]="$LDFLAGS"
@@ -1121,7 +1123,7 @@ function set_globals {
   LDFLAGS_[29]=$LDFLAGS
   BUILD[29]="ninja -C build -j $MAKEJ"
   INSTALL[29]="ninja -C build install"
-  
+
   #####
   # whisper.cpp
   CONFIG[30]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -D BUILD_SHARED_LIBS=ON -D GGML_NATIVE=OFF -D GGML_AVX2=OFF -D WHISPER_BUILD_SERVER=OFF -D WHISPER_BUILD_TESTS=OFF"
@@ -1196,7 +1198,7 @@ function install_shotcut_linux {
   cmd install -p -c COPYING "$FINAL_INSTALL_DIR"
   cmd install -p -c "$QTDIR"/translations/qt_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
   cmd install -p -c "$QTDIR"/translations/qtbase_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
-  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,WaylandClient,WaylandEglClientHwIntegration,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
+  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,WaylandClient,WaylandEglClientHwIntegration,WebSockets,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
   cmd install -p -c "$QTDIR"/lib/lib{icudata,icui18n,icuuc}.so* "$FINAL_INSTALL_DIR"/lib
   cmd install -d "$FINAL_INSTALL_DIR"/lib/qt6/sqldrivers
   cmd cp -a "$QTDIR"/plugins/{egldeviceintegrations,generic,iconengines,imageformats,multimedia,platforminputcontexts,platforms,platformthemes,tls,wayland-decoration-client,wayland-graphics-integration-client,wayland-shell-integration,xcbglintegrations} "$FINAL_INSTALL_DIR"/lib/qt6
@@ -1666,7 +1668,7 @@ function configure_compile_install_all {
     configure_compile_install_subproject $DIR
   done
 
-  if [ "$ACTION_ARCHIVE" = "1" ] && [ "$TARGET_OS" = "Linux" ]; then
+  if [ "$TARGET_OS" = "Linux" ]; then
     log Copying some libs from system
     for lib in "$FINAL_INSTALL_DIR"/lib/qt6/{egldeviceintegrations,generic,iconengines,imageformats,multimedia,platforminputcontexts,platforms,platformthemes,tls,wayland-decoration-client,wayland-graphics-integration-client,wayland-shell-integration,xcbglintegrations}/*.so; do
       bundle_libs "$lib"
