@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2023 Meltytech, LLC
+ * Copyright (c) 2013-2025 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,15 +16,19 @@
  */
 
 #include "settings.h"
+
+#include "Logger.h"
+#include "qmltypes/qmlapplication.h"
+
 #include <QApplication>
-#include <QColor>
-#include <QLocale>
-#include <QStandardPaths>
-#include <QFile>
-#include <QDir>
-#include <QMediaDevices>
 #include <QAudioDevice>
-#include <Logger.h>
+#include <QColor>
+#include <QDir>
+#include <QFile>
+#include <QLocale>
+#include <QMediaDevices>
+#include <QStandardPaths>
+#include <qdesktopservices.h>
 
 static const QString APP_DATA_DIR_KEY("appdatadir");
 static const QString SHOTCUT_INI_FILENAME("/shotcut.ini");
@@ -33,6 +37,7 @@ static QScopedPointer<ShotcutSettings> instance;
 static QString appDataForSession;
 static const int kMaximumTrackHeight = 125;
 static const QString kRecentKey("recent");
+static const QString kProjectsKey("projects");
 
 ShotcutSettings &ShotcutSettings::singleton()
 {
@@ -40,8 +45,10 @@ ShotcutSettings &ShotcutSettings::singleton()
         if (appDataForSession.isEmpty()) {
             instance.reset(new ShotcutSettings);
             if (instance->settings.value(APP_DATA_DIR_KEY).isValid()
-                    && QFile::exists(instance->settings.value(APP_DATA_DIR_KEY).toString() + SHOTCUT_INI_FILENAME) )
-                instance.reset(new ShotcutSettings(instance->settings.value(APP_DATA_DIR_KEY).toString()));
+                && QFile::exists(instance->settings.value(APP_DATA_DIR_KEY).toString()
+                                 + SHOTCUT_INI_FILENAME))
+                instance.reset(
+                    new ShotcutSettings(instance->settings.value(APP_DATA_DIR_KEY).toString()));
         } else {
             instance.reset(new ShotcutSettings(appDataForSession));
         }
@@ -83,7 +90,7 @@ void ShotcutSettings::migrateRecent()
         }
         setRecent(newRecents);
         m_recent.sync();
-//        settings.remove("recent");
+        //        settings.remove("recent");
         settings.sync();
     }
 }
@@ -102,16 +109,20 @@ void ShotcutSettings::migrateLayout()
 
 void ShotcutSettings::log()
 {
-    LOG_DEBUG() << "language" << language();
-    LOG_DEBUG() << "deinterlacer" << playerDeinterlacer();
-    LOG_DEBUG() << "external monitor" << playerExternal();
-    LOG_DEBUG() << "GPU processing" << playerGPU();
-    LOG_DEBUG() << "interpolation" << playerInterpolation();
-    LOG_DEBUG() << "video mode" << playerProfile();
-    LOG_DEBUG() << "realtime" << playerRealtime();
-    LOG_DEBUG() << "audio channels" << playerAudioChannels();
-#ifdef Q_OS_WIN
-    LOG_DEBUG() << "display method" << drawMethod();
+    LOG_INFO() << "language" << language();
+    LOG_INFO() << "deinterlacer" << playerDeinterlacer();
+    LOG_INFO() << "external monitor" << playerExternal();
+    LOG_INFO() << "GPU processing" << playerGPU();
+    LOG_INFO() << "interpolation" << playerInterpolation();
+    LOG_INFO() << "video mode" << playerProfile();
+    LOG_INFO() << "realtime" << playerRealtime();
+    LOG_INFO() << "audio channels" << playerAudioChannels();
+#if defined(Q_OS_WIN) || defined(Q_OS_LINUX)
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        LOG_INFO() << "audio driver" << ::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        LOG_INFO() << "audio driver" << playerAudioDriver();
+    }
 #endif
 }
 
@@ -140,8 +151,9 @@ void ShotcutSettings::setImageDuration(double d)
 
 QString ShotcutSettings::openPath() const
 {
-    return settings.value("openPath",
-                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings
+        .value("openPath", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation))
+        .toString();
 }
 
 void ShotcutSettings::setOpenPath(const QString &s)
@@ -152,8 +164,9 @@ void ShotcutSettings::setOpenPath(const QString &s)
 
 QString ShotcutSettings::savePath() const
 {
-    return settings.value("savePath",
-                          QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation)).toString();
+    return settings
+        .value("savePath", QStandardPaths::standardLocations(QStandardPaths::DocumentsLocation))
+        .toString();
 }
 
 void ShotcutSettings::setSavePath(const QString &s)
@@ -175,6 +188,30 @@ void ShotcutSettings::setRecent(const QStringList &ls)
         m_recent.setValue(kRecentKey, ls);
 }
 
+QStringList ShotcutSettings::projects()
+{
+    auto ls = m_recent.value(kProjectsKey).toStringList();
+    if (ls.isEmpty()) {
+        for (auto &r : recent()) {
+            if (r.endsWith(".mlt"))
+                ls << r;
+        }
+        // Prevent entering this block repeatedly
+        if (ls.isEmpty())
+            ls << QString();
+        setProjects(ls);
+    }
+    return ls;
+}
+
+void ShotcutSettings::setProjects(const QStringList &ls)
+{
+    if (ls.isEmpty())
+        m_recent.remove(kProjectsKey);
+    else if (!clearRecent())
+        m_recent.setValue(kProjectsKey, ls);
+}
+
 QString ShotcutSettings::theme() const
 {
     return settings.value("theme", "dark").toString();
@@ -291,6 +328,116 @@ void ShotcutSettings::setViewMode(const QString &viewMode)
     emit viewModeChanged();
 }
 
+QString ShotcutSettings::filesViewMode() const
+{
+    return settings.value("files/viewMode", QLatin1String("tiled")).toString();
+}
+
+void ShotcutSettings::setFilesViewMode(const QString &viewMode)
+{
+    settings.setValue("files/viewMode", viewMode);
+    emit filesViewModeChanged();
+}
+
+QStringList ShotcutSettings::filesLocations() const
+{
+    QStringList result;
+    for (const auto &s : settings.value("files/locations").toStringList()) {
+        if (!s.startsWith("__"))
+            result << s;
+    }
+    return result;
+}
+
+QString ShotcutSettings::filesLocationPath(const QString &name) const
+{
+    QString key = QStringLiteral("files/location/%1").arg(name);
+    return settings.value(key).toString();
+}
+
+bool ShotcutSettings::setFilesLocation(const QString &name, const QString &path)
+{
+    bool isNew = false;
+    QStringList locations = filesLocations();
+    if (!locations.contains(name)) {
+        isNew = true;
+        locations.append(name);
+        settings.setValue("files/locations", locations);
+    }
+    settings.setValue("files/location/" + name, path);
+    return isNew;
+}
+
+bool ShotcutSettings::removeFilesLocation(const QString &name)
+{
+    QStringList list = filesLocations();
+    int index = list.indexOf(name);
+    if (index > -1) {
+        list.removeAt(index);
+        if (list.isEmpty())
+            settings.remove("files/locations");
+        else
+            settings.setValue("files/locations", list);
+        settings.remove("files/location/" + name);
+        return true;
+    }
+    return false;
+}
+
+QStringList ShotcutSettings::filesOpenOther(const QString &type) const
+{
+    return settings.value("files/openOther/" + type).toStringList();
+}
+
+void ShotcutSettings::setFilesOpenOther(const QString &type, const QString &filePath)
+{
+    QStringList filePaths = filesOpenOther(type);
+    filePaths.removeAll(filePath);
+    filePaths.append(filePath);
+    settings.setValue("files/openOther/" + type, filePaths);
+}
+
+bool ShotcutSettings::removeFilesOpenOther(const QString &type, const QString &filePath)
+{
+    QStringList list = filesOpenOther(type);
+    int index = list.indexOf(filePath);
+    if (index > -1) {
+        list.removeAt(index);
+        if (list.isEmpty())
+            settings.remove("files/openOther/" + type);
+        else
+            settings.setValue("files/openOther/" + type, list);
+        return true;
+    }
+    return false;
+}
+
+QString ShotcutSettings::filesCurrentDir() const
+{
+    const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
+    auto path = settings.value("files/currentDir", ls.first()).toString();
+    if (!QFile::exists(path)) {
+        LOG_DEBUG() << "dir does not exist:" << QDir::toNativeSeparators(path);
+        path = ls.first();
+    }
+    return path;
+}
+
+void ShotcutSettings::setFilesCurrentDir(const QString &s)
+{
+    settings.setValue("files/currentDir", s);
+}
+
+bool ShotcutSettings::filesFoldersOpen() const
+{
+    return settings.value("files/foldersOpen", true).toBool();
+}
+
+void ShotcutSettings::setFilesFoldersOpen(bool b)
+{
+    settings.setValue("files/foldersOpen", b);
+}
+
 QString ShotcutSettings::exportFrameSuffix() const
 {
     return settings.value("exportFrameSuffix", ".png").toString();
@@ -303,8 +450,9 @@ void ShotcutSettings::setExportFrameSuffix(const QString &exportFrameSuffix)
 
 QString ShotcutSettings::encodePath() const
 {
-    return settings.value("encode/path",
-                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings
+        .value("encode/path", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation))
+        .toString();
 }
 
 void ShotcutSettings::setEncodePath(const QString &s)
@@ -458,6 +606,16 @@ void ShotcutSettings::setPlayerJACK(bool b)
     settings.setValue("player/jack", b);
 }
 
+int ShotcutSettings::playerDecklinkGamma() const
+{
+    return settings.value("player/decklinkGamma", 0).toInt();
+}
+
+void ShotcutSettings::setPlayerDecklinkGamma(int i)
+{
+    settings.setValue("player/decklinkGamma", i);
+}
+
 int ShotcutSettings::playerKeyerMode() const
 {
     return settings.value("player/keyer", 0).toInt();
@@ -568,6 +726,35 @@ void ShotcutSettings::setPlayerJumpSeconds(double i)
     settings.setValue("player/jumpSeconds", i);
 }
 
+QString ShotcutSettings::playerAudioDriver() const
+{
+#if defined(Q_OS_WIN)
+    auto s = playerAudioChannels() > 2 ? "directsound" : "winmm";
+#else
+    auto s = "pulseaudio";
+#endif
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        return ::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        return settings.value("player/audioDriver", s).toString();
+    }
+}
+
+void ShotcutSettings::setPlayerAudioDriver(const QString &s)
+{
+    settings.setValue("player/audioDriver", s);
+}
+
+bool ShotcutSettings::playerPauseAfterSeek() const
+{
+    return settings.value("player/pauseAfterSeek", true).toBool();
+}
+
+void ShotcutSettings::setPlayerPauseAfterSeek(bool b)
+{
+    settings.setValue("player/pauseAfterSeek", b);
+}
+
 QString ShotcutSettings::playlistThumbnails() const
 {
     return settings.value("playlist/thumbnails", "small").toString();
@@ -589,6 +776,16 @@ void ShotcutSettings::setPlaylistAutoplay(bool b)
     settings.setValue("playlist/autoplay", b);
 }
 
+bool ShotcutSettings::playlistShowColumn(const QString &column)
+{
+    return settings.value("playlist/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setPlaylistShowColumn(const QString &column, bool b)
+{
+    settings.setValue("playlist/columns/" + column, b);
+}
+
 bool ShotcutSettings::timelineDragScrub() const
 {
     return settings.value("timeline/dragScrub", false).toBool();
@@ -666,17 +863,6 @@ void ShotcutSettings::setTimelineSnap(bool b)
     emit timelineSnapChanged();
 }
 
-bool ShotcutSettings::timelineCenterPlayhead() const
-{
-    return settings.value("timeline/centerPlayhead", false).toBool();
-}
-
-void ShotcutSettings::setTimelineCenterPlayhead(bool b)
-{
-    settings.setValue("timeline/centerPlayhead", b);
-    emit timelineCenterPlayheadChanged();
-}
-
 int ShotcutSettings::timelineTrackHeight() const
 {
     return qMin(settings.value("timeline/trackHeight", 50).toInt(), kMaximumTrackHeight);
@@ -737,6 +923,58 @@ void ShotcutSettings::setTimelinePreviewTransition(bool b)
     settings.setValue("timeline/previewTransition", b);
 }
 
+void ShotcutSettings::setTimelineScrolling(ShotcutSettings::TimelineScrolling value)
+{
+    settings.remove("timeline/centerPlayhead");
+    settings.setValue("timeline/scrolling", value);
+    emit timelineScrollingChanged();
+}
+
+ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
+{
+    if (settings.contains("timeline/centerPlayhead")
+        && settings.value("timeline/centerPlayhead").toBool())
+        return ShotcutSettings::TimelineScrolling::CenterPlayhead;
+    else
+        return ShotcutSettings::TimelineScrolling(
+            settings.value("timeline/scrolling", PageScrolling).toInt());
+}
+
+bool ShotcutSettings::timelineAutoAddTracks() const
+{
+    return settings.value("timeline/autoAddTracks", false).toBool();
+}
+
+void ShotcutSettings::setTimelineAutoAddTracks(bool b)
+{
+    if (b != timelineAutoAddTracks()) {
+        settings.setValue("timeline/autoAddTracks", b);
+        emit timelineAutoAddTracksChanged();
+    }
+}
+
+bool ShotcutSettings::timelineRectangleSelect() const
+{
+    return settings.value("timeline/rectangleSelect", true).toBool();
+}
+
+void ShotcutSettings::setTimelineRectangleSelect(bool b)
+{
+    settings.setValue("timeline/rectangleSelect", b);
+    emit timelineRectangleSelectChanged();
+}
+
+bool ShotcutSettings::timelineAdjustGain() const
+{
+    return settings.value("timeline/adjustGain", true).toBool();
+}
+
+void ShotcutSettings::setTimelineAdjustGain(bool b)
+{
+    settings.setValue("timeline/adjustGain", b);
+    emit timelineAdjustGainChanged();
+}
+
 QString ShotcutSettings::filterFavorite(const QString &filterName)
 {
     return settings.value("filter/favorite/" + filterName, "").toString();
@@ -768,7 +1006,6 @@ void ShotcutSettings::setAudioOutDuration(double d)
     emit audioOutDurationChanged();
 }
 
-
 double ShotcutSettings::videoInDuration() const
 {
     return settings.value("filter/videoInDuration", 1.0).toDouble();
@@ -791,6 +1028,28 @@ void ShotcutSettings::setVideoOutDuration(double d)
     emit videoOutDurationChanged();
 }
 
+int ShotcutSettings::audioInCurve() const
+{
+    return settings.value("filter/audioInCurve", mlt_keyframe_linear).toInt();
+}
+
+void ShotcutSettings::setAudioInCurve(int c)
+{
+    settings.setValue("filter/audioInCurve", c);
+    emit audioInCurveChanged();
+}
+
+int ShotcutSettings::audioOutCurve() const
+{
+    return settings.value("filter/audioOutCurve", mlt_keyframe_linear).toInt();
+}
+
+void ShotcutSettings::setAudioOutCurve(int c)
+{
+    settings.setValue("filter/audioOutCurve", c);
+    emit audioOutCurveChanged();
+}
+
 bool ShotcutSettings::askOutputFilter() const
 {
     return settings.value("filter/askOutput", true).toBool();
@@ -845,7 +1104,7 @@ int ShotcutSettings::getMarkerSortColumn()
 
 Qt::SortOrder ShotcutSettings::getMarkerSortOrder()
 {
-    return (Qt::SortOrder)settings.value("markers/sortOrder", Qt::AscendingOrder).toInt();
+    return (Qt::SortOrder) settings.value("markers/sortOrder", Qt::AscendingOrder).toInt();
 }
 
 int ShotcutSettings::drawMethod() const
@@ -892,6 +1151,16 @@ void ShotcutSettings::setAskUpgradeAutomatic(bool b)
     settings.setValue("askUpgradeAutmatic", b);
 }
 
+bool ShotcutSettings::askChangeVideoMode()
+{
+    return settings.value("askChangeVideoMode", true).toBool();
+}
+
+void ShotcutSettings::setAskChangeVideoMode(bool b)
+{
+    settings.setValue("askChangeVideoMode", b);
+}
+
 void ShotcutSettings::sync()
 {
     settings.sync();
@@ -943,7 +1212,8 @@ QStringList ShotcutSettings::layouts() const
     return result;
 }
 
-bool ShotcutSettings::setLayout(const QString &name, const QByteArray &geometry,
+bool ShotcutSettings::setLayout(const QString &name,
+                                const QByteArray &geometry,
                                 const QByteArray &state)
 {
     bool isNew = false;
@@ -953,20 +1223,20 @@ bool ShotcutSettings::setLayout(const QString &name, const QByteArray &geometry,
         layouts.append(name);
         settings.setValue("layout/layouts", layouts);
     }
-    settings.setValue(QString("layout/%1_%2").arg(name, "geometry"), geometry);
-    settings.setValue(QString("layout/%1_%2").arg(name, "state"), state);
+    settings.setValue(QStringLiteral("layout/%1_%2").arg(name, "geometry"), geometry);
+    settings.setValue(QStringLiteral("layout/%1_%2").arg(name, "state"), state);
     return isNew;
 }
 
 QByteArray ShotcutSettings::layoutGeometry(const QString &name)
 {
-    QString key = QString("layout/%1_geometry").arg(name);
+    QString key = QStringLiteral("layout/%1_geometry").arg(name);
     return settings.value(key).toByteArray();
 }
 
 QByteArray ShotcutSettings::layoutState(const QString &name)
 {
-    QString key = QString("layout/%1_state").arg(name);
+    QString key = QStringLiteral("layout/%1_state").arg(name);
     return settings.value(key).toByteArray();
 }
 
@@ -980,8 +1250,8 @@ bool ShotcutSettings::removeLayout(const QString &name)
             settings.remove("layout/layouts");
         else
             settings.setValue("layout/layouts", list);
-        settings.remove(QString("layout/%1_%2").arg(name, "geometry"));
-        settings.remove(QString("layout/%1_%2").arg(name, "state"));
+        settings.remove(QStringLiteral("layout/%1_%2").arg(name, "geometry"));
+        settings.remove(QStringLiteral("layout/%1_%2").arg(name, "state"));
         return true;
     }
     return false;
@@ -1009,8 +1279,9 @@ void ShotcutSettings::setClearRecent(bool b)
 
 QString ShotcutSettings::projectsFolder() const
 {
-    return settings.value("projectsFolder",
-                          QStandardPaths::standardLocations(QStandardPaths::MoviesLocation)).toString();
+    return settings
+        .value("projectsFolder", QStandardPaths::standardLocations(QStandardPaths::MoviesLocation))
+        .toString();
 }
 
 void ShotcutSettings::setProjectsFolder(const QString &path)
@@ -1020,7 +1291,7 @@ void ShotcutSettings::setProjectsFolder(const QString &path)
 
 QString ShotcutSettings::audioInput() const
 {
-    QString defaultValue  = "default";
+    QString defaultValue = "default";
 #if defined(Q_OS_MAC) || defined(Q_OS_WIN)
     for (const auto &deviceInfo : QMediaDevices::audioInputs()) {
         defaultValue = deviceInfo.description();
@@ -1141,6 +1412,185 @@ QList<QKeySequence> ShotcutSettings::shortcuts(const QString &name)
     return shortcuts;
 }
 
+double ShotcutSettings::slideshowImageDuration(double defaultSeconds) const
+{
+    return settings.value("slideshow/clipDuration", defaultSeconds).toDouble();
+}
+
+void ShotcutSettings::setSlideshowImageDuration(double seconds)
+{
+    settings.setValue("slideshow/clipDuration", seconds);
+}
+
+double ShotcutSettings::slideshowAudioVideoDuration(double defaultSeconds) const
+{
+    return settings.value("slideshow/audioVideoDuration", defaultSeconds).toDouble();
+}
+
+void ShotcutSettings::setSlideshowAudioVideoDuration(double seconds)
+{
+    settings.setValue("slideshow/audioVideoDuration", seconds);
+}
+
+int ShotcutSettings::slideshowAspectConversion(int defaultAspectConversion) const
+{
+    return settings.value("slideshow/aspectConversion", defaultAspectConversion).toInt();
+}
+
+void ShotcutSettings::setSlideshowAspectConversion(int aspectConversion)
+{
+    settings.setValue("slideshow/aspectConversion", aspectConversion);
+}
+
+int ShotcutSettings::slideshowZoomPercent(int defaultZoomPercent) const
+{
+    return settings.value("slideshow/zoomPercent", defaultZoomPercent).toInt();
+}
+
+void ShotcutSettings::setSlideshowZoomPercent(int zoomPercent)
+{
+    settings.setValue("slideshow/zoomPercent", zoomPercent);
+}
+
+double ShotcutSettings::slideshowTransitionDuration(double defaultTransitionDuration) const
+{
+    return settings.value("slideshow/transitionDuration", defaultTransitionDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowTransitionDuration(double transitionDuration)
+{
+    settings.setValue("slideshow/transitionDuration", transitionDuration);
+}
+
+int ShotcutSettings::slideshowTransitionStyle(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionStyle", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionStyle(int transitionStyle)
+{
+    settings.setValue("slideshow/transitionStyle", transitionStyle);
+}
+
+int ShotcutSettings::slideshowTransitionSoftness(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionSoftness", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionSoftness(int transitionSoftness)
+{
+    settings.setValue("slideshow/transitionSoftness", transitionSoftness);
+}
+
+bool ShotcutSettings::keyframesDragScrub() const
+{
+    return settings.value("keyframes/dragScrub", false).toBool();
+}
+
+void ShotcutSettings::setKeyframesDragScrub(bool b)
+{
+    settings.setValue("keyframes/dragScrub", b);
+    emit keyframesDragScrubChanged();
+}
+
+void ShotcutSettings::setSubtitlesShowColumn(const QString &column, bool b)
+{
+    settings.setValue("subtitles/columns/" + column, b);
+}
+
+bool ShotcutSettings::subtitlesShowColumn(const QString &column) const
+{
+    return settings.value("subtitles/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setSubtitlesTrackTimeline(bool b)
+{
+    settings.setValue("subtitles/trackTimeline", b);
+}
+
+bool ShotcutSettings::subtitlesTrackTimeline() const
+{
+    return settings.value("subtitles/trackTimeline", true).toBool();
+}
+
+void ShotcutSettings::setSubtitlesShowPrevNext(bool b)
+{
+    settings.setValue("subtitles/showPrevNext", b);
+}
+
+bool ShotcutSettings::subtitlesShowPrevNext() const
+{
+    return settings.value("subtitles/showPrevNext", true).toBool();
+}
+
+QString ShotcutSettings::speechLanguage() const
+{
+    return settings.value("speech/language", QStringLiteral("a")).toString();
+}
+
+void ShotcutSettings::setSpeechLanguage(const QString &code)
+{
+    settings.setValue("speech/language", code);
+}
+
+QString ShotcutSettings::speechVoice() const
+{
+    return settings.value("speech/voice", QString()).toString();
+}
+
+void ShotcutSettings::setSpeechVoice(const QString &voiceId)
+{
+    settings.setValue("speech/voice", voiceId);
+}
+
+double ShotcutSettings::speechSpeed() const
+{
+    return settings.value("speech/speed", 1.0).toDouble();
+}
+
+void ShotcutSettings::setSpeechSpeed(double speed)
+{
+    settings.setValue("speech/speed", speed);
+}
+
+void ShotcutSettings::setWhisperExe(const QString &path)
+{
+    settings.setValue("subtitles/whisperExe", path);
+}
+
+QString ShotcutSettings::whisperExe()
+{
+    QDir dir(qApp->applicationDirPath());
+#if defined(Q_OS_WIN)
+    auto exe = "whisper-cli.exe";
+#else
+    auto exe = "whisper-cli";
+#endif
+    return settings.value("subtitles/whisperExe", dir.absoluteFilePath(exe)).toString();
+}
+
+void ShotcutSettings::setWhisperModel(const QString &path)
+{
+    settings.setValue("subtitles/whisperModel", path);
+}
+
+QString ShotcutSettings::whisperModel()
+{
+    QDir dataPath = QmlApplication::dataDir();
+    dataPath.cd("shotcut/whisper_models");
+    return settings.value("subtitles/whisperModel", "").toString();
+}
+
+void ShotcutSettings::setNotesZoom(int zoom)
+{
+    settings.setValue("notes/zoom", zoom);
+}
+
+int ShotcutSettings::notesZoom() const
+{
+    return settings.value("notes/zoom", 0).toInt();
+}
+
 void ShotcutSettings::reset()
 {
     for (auto &key : settings.allKeys()) {
@@ -1150,10 +1600,75 @@ void ShotcutSettings::reset()
 
 int ShotcutSettings::undoLimit() const
 {
-    return settings.value("undoLimit", 1000).toInt();
+    return settings.value("undoLimit", 50).toInt();
 }
 
 bool ShotcutSettings::warnLowMemory() const
 {
     return settings.value("warnLowMemory", true).toBool();
 }
+
+int ShotcutSettings::backupPeriod() const
+{
+    return settings.value("backupPeriod", 24 * 60).toInt();
+}
+
+void ShotcutSettings::setBackupPeriod(int minutes)
+{
+    settings.setValue("backupPeriod", minutes);
+}
+
+mlt_time_format ShotcutSettings::timeFormat() const
+{
+    return (mlt_time_format) settings.value("timeFormat", mlt_time_clock).toInt();
+}
+
+void ShotcutSettings::setTimeFormat(int format)
+{
+    settings.setValue("timeFormat", format);
+    emit timeFormatChanged();
+}
+
+bool ShotcutSettings::askFlatpakWrappers()
+{
+    return settings.value("flatpakWrappers", true).toBool();
+}
+
+void ShotcutSettings::setAskFlatpakWrappers(bool b)
+{
+    settings.setValue("flatpakWrappers", b);
+}
+
+QString ShotcutSettings::dockerPath() const
+{
+#if defined(Q_OS_MAC)
+    return settings.value("dockerPath", "/usr/local/bin/docker").toString();
+#elif defined(Q_OS_WIN)
+    return settings.value("dockerPath", "C:/Program Files/Docker/Docker/resources/bin/docker.exe")
+        .toString();
+#else
+    return settings.value("dockerPath", "docker").toString();
+#endif
+}
+
+void ShotcutSettings::setDockerPath(const QString &path)
+{
+    settings.setValue("dockerPath", path);
+}
+
+QString ShotcutSettings::chromiumPath() const
+{
+#if defined(Q_OS_MAC)
+    return settings.value("dockerPath", "/Applications/Google Chrome.app").toString();
+#elif defined(Q_OS_WIN)
+    return settings.value("chromiumPath", "C:/Program Files/Google/Chrome/Application/chrome.exe")
+        .toString();
+#else
+    return settings.value("chromiumPath", "chromium").toString();
+#endif
+}
+
+void ShotcutSettings::setChromiumPath(const QString &path)
+{
+    settings.setValue("chromiumPath", path);
+}
