@@ -17,6 +17,7 @@
 
 #include "util.h"
 
+#include "FlatpakWrapperGenerator.h"
 #include "Logger.h"
 #include "dialogs/transcodedialog.h"
 #include "mainwindow.h"
@@ -41,6 +42,8 @@
 #include <QMediaDevices>
 #include <QMessageBox>
 #include <QProcess>
+#include <QRegularExpression>
+#include <QStandardPaths>
 #include <QStorageInfo>
 #include <QStringList>
 #include <QTemporaryFile>
@@ -800,7 +803,7 @@ QString Util::trcString(int trc)
 bool Util::trcIsCompatible(int trc)
 {
     // Transfer characteristics > SMPTE240M Probably need conversion except IEC61966-2-4 is OK
-    return trc <= 7 || trc == 11 || trc == 13 || trc == 18;
+    return trc <= 7 || trc == 11 || trc == 13 || trc == 14 || trc == 15 || trc == 18;
 }
 
 QString Util::getConversionAdvice(Mlt::Producer *producer)
@@ -918,3 +921,246 @@ bool Util::hasiPhoneAmbisonic(Mlt::Producer *producer)
            && !::qstrcmp(producer->get("meta.media.1.stream.type"), "audio")
            && QString(producer->get("meta.attr.com.apple.quicktime.model.markup")).contains("iPhone");
 }
+
+bool Util::installFlatpakWrappers(QWidget *parent)
+{
+    if (!Settings.askFlatpakWrappers())
+        return false;
+    QMessageBox dialog(QMessageBox::Question,
+                       qApp->applicationName(),
+                       parent->tr(
+                           "<p>Do you want use a Flatpak?</p>"
+                           "<p>Click <b>Yes</b> to install/update the Flatpak wrapper scripts "
+                           "in\n<b>Files > Home > Flatpaks</b>.</p>"
+                           "<p>Tip: Add <b><tt>~/Flatpaks</tt></b> to your <b><tt>$PATH</tt></b> "
+                           "to make them more "
+                           "convenient on the command line.</p>"),
+                       QMessageBox::No | QMessageBox::Yes,
+                       parent);
+    dialog.setCheckBox(new QCheckBox(parent->tr("Do not show this anymore.")));
+    dialog.setWindowModality(QmlApplication::dialogModality());
+    dialog.setDefaultButton(QMessageBox::Yes);
+    dialog.setEscapeButton(QMessageBox::No);
+    int r = dialog.exec();
+    if (dialog.checkBox()->isChecked())
+        Settings.setAskFlatpakWrappers(false);
+    if (r == QMessageBox::Yes) {
+        FlatpakWrapperGenerator flatpaks;
+        const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
+        auto home = QDir(ls.first());
+        const auto subdir = QStringLiteral("Flatpaks");
+        if (!home.cd(subdir)) {
+            if (home.mkdir(subdir))
+                home.cd(subdir);
+            else
+                return false;
+        }
+        flatpaks.setOutputDir(home.absolutePath());
+        flatpaks.setForce(true);
+        flatpaks.generateAllInstalled();
+        return true;
+    }
+    return false;
+}
+
+QString Util::getExecutable(QWidget *parent)
+{
+    QString dir;
+    QString filter;
+#if defined(Q_OS_WIN)
+    dir = QStringLiteral("C:/ProgramData/Microsoft/Windows/Start Menu/Programs");
+    filter = parent->tr("Executable Files (*.exe);;All Files (*)");
+#elif defined(Q_OS_MAC)
+    const auto ls = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
+    LOG_DEBUG() << ls;
+    dir = ls.last();
+#elif defined(Q_OS_LINUX)
+    if (Util::installFlatpakWrappers(parent)) {
+        const auto ls = QStandardPaths::standardLocations(QStandardPaths::HomeLocation);
+        auto home = QDir(ls.first());
+        home.cd("Flatpaks");
+        dir = home.absolutePath();
+    } else {
+        dir = QStringLiteral("/usr/bin");
+    }
+#endif
+    return QFileDialog::getOpenFileName(MAIN.window(),
+                                        parent->tr("Choose Executable"),
+                                        dir,
+                                        filter,
+                                        nullptr,
+                                        Util::getFileDialogOptions());
+}
+
+QPair<bool, bool> Util::dockerStatus(const QString &imageName)
+{
+    // Check if docker executable is available by running 'docker --version'.
+    QProcess proc;
+    proc.start(Settings.dockerPath(), {"--version"});
+    if (!proc.waitForStarted(1000)) {
+        return qMakePair(false, false);
+    }
+    // Keep the timeout short to avoid UI stall.
+    if (!proc.waitForFinished(2000)) {
+        proc.kill();
+        return qMakePair(false, false);
+    }
+    bool dockerOk = proc.exitStatus() == QProcess::NormalExit && proc.exitCode() == 0;
+    if (!dockerOk) {
+        return qMakePair(false, false);
+    }
+    if (imageName.isEmpty()) {
+        return qMakePair(true, false);
+    }
+
+    // Query local images for the given name (may include tag). We avoid pulling.
+    // Use 'docker image inspect <imageName>' which returns 0 if present.
+    QProcess procImage;
+    procImage.start(Settings.dockerPath(), {"image", "inspect", imageName});
+    if (!procImage.waitForStarted(1000)) {
+        return qMakePair(true, false);
+    }
+    if (!procImage.waitForFinished(5000)) { // allow a bit more time here
+        procImage.kill();
+        return qMakePair(true, false);
+    }
+    bool imageOk = procImage.exitStatus() == QProcess::NormalExit && procImage.exitCode() == 0;
+    return qMakePair(true, imageOk);
+}
+
+// Helper to extract digest from 'docker manifest inspect' output.
+static QString digestFromManifestInspect(const QByteArray &json)
+{
+    auto s = QString::fromUtf8(json);
+    auto idx = s.indexOf("sha256:");
+    if (idx >= 0 && idx + 71 <= s.size()) {
+        return s.mid(idx, 71);
+    }
+    return QString();
+}
+
+static QSet<QString> dockerCurrentState;
+
+bool Util::isDockerImageCurrent(const QString &imageRef)
+{
+    if (imageRef.isEmpty()) {
+        return false;
+    }
+
+    // TODO: This comparison is not working outside of the machine on which I built the image.
+    // In the meantime, use check once per session per image ref.
+    if (dockerCurrentState.contains(imageRef))
+        return true;
+    dockerCurrentState << imageRef;
+    return false;
+
+    // Inspect (local/remote combined behavior) - this is a simplistic approach.
+    QProcess localProc;
+    localProc.start(Settings.dockerPath(), {"image", "inspect", imageRef});
+    if (!localProc.waitForStarted(1000) || !localProc.waitForFinished(4000)) {
+        if (localProc.state() != QProcess::NotRunning)
+            localProc.kill();
+    }
+    QString localDigest;
+    if (localProc.exitStatus() == QProcess::NormalExit && localProc.exitCode() == 0) {
+        localDigest = digestFromManifestInspect(localProc.readAllStandardOutput());
+    }
+
+    // Run again expecting remote freshness (will hit registry) without pulling.
+    QProcess remoteProc;
+    remoteProc.start(Settings.dockerPath(), {"manifest", "inspect", imageRef});
+    if (!remoteProc.waitForStarted(1000) || !remoteProc.waitForFinished(15000)) {
+        if (remoteProc.state() != QProcess::NotRunning)
+            remoteProc.kill();
+        return false;
+    }
+    if (remoteProc.exitStatus() != QProcess::NormalExit || remoteProc.exitCode() != 0) {
+        return false;
+    }
+    auto remoteDigest = digestFromManifestInspect(remoteProc.readAllStandardOutput());
+    return !remoteDigest.isEmpty() && !localDigest.isEmpty() && localDigest == remoteDigest;
+}
+
+void Util::isDockerImageCurrentAsync(const QString &imageRef,
+                                     QObject *receiver,
+                                     std::function<void(bool)> callback)
+{
+    if (!callback) {
+        return; // nothing to do
+    }
+    if (imageRef.isEmpty()) {
+        callback(false);
+        return;
+    }
+
+    // TODO: This comparison is not working outside of the machine on which I built the image.
+    // In the meantime, use check once per session per image ref.
+    if (dockerCurrentState.contains(imageRef)) {
+        callback(true);
+        return;
+    }
+    dockerCurrentState << imageRef;
+    callback(false);
+    return;
+
+    auto emitResult = [callback](bool result) {
+        QMetaObject::invokeMethod(
+            qApp, [callback, result]() { callback(result); }, Qt::QueuedConnection);
+    };
+
+    // Start with local inspect.
+    auto *localProc = new QProcess(receiver);
+    QObject::connect(localProc,
+                     &QProcess::errorOccurred,
+                     localProc,
+                     [localProc, emitResult](QProcess::ProcessError) {
+                         localProc->deleteLater();
+                         emitResult(false);
+                     });
+    QObject::connect(
+        localProc,
+        QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+        localProc,
+        [imageRef, receiver, emitResult, localProc](int, QProcess::ExitStatus) {
+            QString localDigest;
+            if (localProc->exitStatus() == QProcess::NormalExit && localProc->exitCode() == 0) {
+                localDigest = digestFromManifestInspect(localProc->readAllStandardOutput());
+            }
+            localProc->deleteLater();
+            // Remote manifest inspect regardless; if docker missing it will fail.
+            auto *remoteProc = new QProcess(receiver);
+            QObject::connect(remoteProc,
+                             &QProcess::errorOccurred,
+                             remoteProc,
+                             [remoteProc, emitResult](QProcess::ProcessError) {
+                                 remoteProc->deleteLater();
+                                 emitResult(false);
+                             });
+            QObject::connect(remoteProc,
+                             QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+                             remoteProc,
+                             [emitResult, remoteProc, localDigest](int, QProcess::ExitStatus) {
+                                 QString remoteDigest;
+                                 if (remoteProc->exitStatus() == QProcess::NormalExit
+                                     && remoteProc->exitCode() == 0) {
+                                     remoteDigest = digestFromManifestInspect(
+                                         remoteProc->readAllStandardOutput());
+                                 }
+                                 remoteProc->deleteLater();
+                                 bool current = !remoteDigest.isEmpty() && !localDigest.isEmpty()
+                                                && localDigest == remoteDigest;
+                                 emitResult(current);
+                             });
+            LOG_DEBUG() << "docker manifest inspect" << imageRef;
+            remoteProc->start(Settings.dockerPath(), {"manifest", "inspect", imageRef});
+        });
+    LOG_DEBUG() << "docker image inspect" << imageRef;
+    localProc->start(Settings.dockerPath(), {"image", "inspect", imageRef});
+}
+
+bool Util::isChromiumAvailable()
+{
+    // Check if Chromium executable file exists and is executable
+    QFileInfo fileInfo(Settings.chromiumPath());
+    return fileInfo.exists() && fileInfo.isExecutable();
+}
